# Google Search Console MCP for Claude

This is a Desktop Extension for Claude that allows you to fetch and analyze Google Search Console data as a tool.

## Features

- **List Sites**: Get a list of all accessible Search Console sites
- **Search Analytics**: Retrieve search performance data with flexible date ranges and dimensions
- **Daily Reports**: Get daily search performance summaries
- **URL Inspection**: Inspect specific URLs to get their Search Console data

## Setup

### 1. Create a Google Cloud Project

1. Go to the [Google Cloud Console](https://console.cloud.google.com/)
2. Create a new project or select an existing one
3. Enable the Search Console API for your project

### 2. Create a Service Account

1. In the Google Cloud Console, go to "IAM & Admin" > "Service Accounts"
2. Click "Create Service Account"
3. Give it a name (e.g., "search-console-mcp")
4. Grant the "Search Console API User" role
5. Create and download the JSON key file

### 3. Add Service Account to Search Console

1. Go to [Google Search Console](https://search.google.com/search-console)
2. Add your service account email as a user to the properties you want to access
3. Grant "Full" permissions

### 4. Install the Extension

1. Download the `.dxt` file from the releases
2. Install it in Claude Desktop
3. Configure the extension with your service account JSON key file
4. Optionally set a default site URL

## Usage

### List Sites

```
List all accessible Search Console sites
```

### Get Search Analytics

```
Get search analytics for the last 7 days with query and page dimensions
```

### Get Daily Report

```
Get yesterday's search performance summary
```

### URL Inspection

```
Inspect the URL https://example.com/page to get its Search Console data
```

## Configuration

- **Service Account Key File**: Required. Select the JSON key file downloaded from Google Cloud Console
- **Default Site URL**: Optional. Set a default site URL to use when not specified in tool calls

## Development

### Prerequisites

- Node.js 18 or later
- pnpm

### Installation

```bash
cd search-console
pnpm install
```

### Running Locally

```bash
pnpm start
```

### Building

```bash
pnpm run build
```

## API Reference

### Tools

#### `list_sites`

Get a list of accessible Search Console sites.

#### `get_search_analytics`

Get search analytics data for a specified date range.

**Parameters:**

- `siteUrl` (optional): Site URL. If omitted, the default value will be used.
- `startDate` (required): Start date in YYYY-MM-DD format.
- `endDate` (required): End date in YYYY-MM-DD format.
- `dimensions` (optional): Dimensions to group by (e.g., ['query', 'page']). Default: ['query']
- `rowLimit` (optional): Maximum number of rows to return. Default: 1000

#### `get_daily_search_report`

Get daily search performance summary for a specified date.

**Parameters:**

- `siteUrl` (optional): Site URL. If omitted, the default value will be used.
- `date` (optional): Date in YYYY-MM-DD format. Defaults to yesterday if omitted.

#### `get_url_inspection`

Inspect a specific URL to get its Search Console data.

**Parameters:**

- `siteUrl` (optional): Site URL. If omitted, the default value will be used.
- `inspectionUrl` (required): The URL to inspect (must be under the site URL)

## Troubleshooting

### Common Issues

1. **Permission Denied**: Make sure your service account has been added to the Search Console property with appropriate permissions.

2. **API Not Enabled**: Ensure the Search Console API is enabled in your Google Cloud project.

3. **Invalid Site URL**: The site URL must match exactly how it appears in Search Console (including http/https and www/non-www).

### Error Messages

- `Site URL is not specified`: Set a default site URL in the extension settings or provide it as a parameter.
- `Failed to list sites`: Check your service account permissions and API enablement.
- `Failed to get search analytics`: Verify the date range and site URL are correct.

## License

MIT License - see [LICENSE](LICENSE) file for details.

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.

## Support

If you encounter any issues, please check the troubleshooting section above or create an issue on GitHub.
