# Google Search Console MCP for Claude

これは、Google Search Console のデータをツールとして取得・分析できる Claude 用のデスクトップ拡張機能です。

## 機能

- **サイト一覧**: アクセス可能な Search Console サイトの一覧を取得
- **検索アナリティクス**: 柔軟な日付範囲とディメンションで検索パフォーマンスデータを取得
- **日次レポート**: 日次の検索パフォーマンスサマリーを取得
- **URL 検査**: 特定の URL を検査して Search Console データを取得

## セットアップ

### 1. Google Cloud プロジェクトの作成

1. [Google Cloud Console](https://console.cloud.google.com/)にアクセス
2. 新しいプロジェクトを作成するか、既存のプロジェクトを選択
3. プロジェクトで Search Console API を有効化

### 2. サービスアカウントの作成

1. Google Cloud Console で「IAM & 管理」>「サービスアカウント」に移動
2. 「サービスアカウントを作成」をクリック
3. 名前を付ける（例：「search-console-mcp」）
4. 「Search Console API ユーザー」ロールを付与
5. JSON キーファイルを作成してダウンロード

### 3. Search Console にサービスアカウントを追加

1. [Google Search Console](https://search.google.com/search-console)にアクセス
2. アクセスしたいプロパティにサービスアカウントのメールアドレスをユーザーとして追加
3. 「完全」権限を付与

### 4. 拡張機能のインストール

1. リリースから`.dxt`ファイルをダウンロード
2. Claude Desktop にインストール
3. サービスアカウントの JSON キーファイルで拡張機能を設定
4. 必要に応じてデフォルトのサイト URL を設定

## 使用方法

### サイト一覧

```
アクセス可能なSearch Consoleサイトをすべて一覧表示
```

### 検索アナリティクス

```
過去7日間のクエリとページディメンションで検索アナリティクスを取得
```

### 日次レポート

```
昨日の検索パフォーマンスサマリーを取得
```

### URL 検査

```
URL https://example.com/page を検査してSearch Consoleデータを取得
```

## 設定

- **サービスアカウントキーファイル**: 必須。Google Cloud Console からダウンロードした JSON キーファイルを選択
- **デフォルトサイト URL**: 任意。ツール呼び出し時に指定されていない場合に使用するデフォルトのサイト URL を設定

## 開発

### 前提条件

- Node.js 18 以降
- pnpm

### インストール

```bash
cd search-console
pnpm install
```

### ローカル実行

```bash
pnpm start
```

### ビルド

```bash
pnpm run build
```

## API リファレンス

### ツール

#### `list_sites`

アクセス可能な Search Console サイトの一覧を取得します。

#### `get_search_analytics`

指定した日付範囲の検索アナリティクスデータを取得します。

**パラメータ:**

- `siteUrl` (任意): サイト URL。省略した場合、デフォルト値が使用されます。
- `startDate` (必須): 開始日（YYYY-MM-DD 形式）。
- `endDate` (必須): 終了日（YYYY-MM-DD 形式）。
- `dimensions` (任意): グループ化するディメンション（例：['query', 'page']）。デフォルト：['query']
- `rowLimit` (任意): 返される最大行数。デフォルト：1000

#### `get_daily_search_report`

指定した日付の日次検索パフォーマンスサマリーを取得します。

**パラメータ:**

- `siteUrl` (任意): サイト URL。省略した場合、デフォルト値が使用されます。
- `date` (任意): 日付（YYYY-MM-DD 形式）。省略した場合、昨日がデフォルトになります。

#### `get_url_inspection`

特定の URL を検査して Search Console データを取得します。

**パラメータ:**

- `siteUrl` (任意): サイト URL。省略した場合、デフォルト値が使用されます。
- `inspectionUrl` (必須): 検査する URL（サイト URL の下にある必要があります）

## トラブルシューティング

### よくある問題

1. **権限が拒否されました**: サービスアカウントが適切な権限で Search Console プロパティに追加されていることを確認してください。

2. **API が有効になっていません**: Google Cloud プロジェクトで Search Console API が有効になっていることを確認してください。

3. **無効なサイト URL**: サイト URL は Search Console に表示されるものと完全に一致する必要があります（http/https や www/non-www を含む）。

### エラーメッセージ

- `Site URL is not specified`: 拡張機能設定でデフォルトのサイト URL を設定するか、パラメータとして提供してください。
- `Failed to list sites`: サービスアカウントの権限と API の有効化を確認してください。
- `Failed to get search analytics`: 日付範囲とサイト URL が正しいことを確認してください。

## ライセンス

MIT ライセンス - 詳細は[LICENSE](LICENSE)ファイルを参照してください。

## 貢献

貢献を歓迎します！プルリクエストを自由に送信してください。

## サポート

問題が発生した場合は、上記のトラブルシューティングセクションを確認するか、GitHub で issue を作成してください。
